# Kinetics analysis program

IOCBIO Kinetics is a cross-platform application for analysis of
different traces, as described by its plugins. While originally
developed for analysis of enzyme kinetics, the other types of traces
can be analyzed as well.

IOCBIO Kinetics is written for use by Laboratory of Systems Biology,
Department of Cybernetics, School of Science, Tallinn University of
Technology. At present, the software is not distributed outside the
laboratory and its use is permitted for laboratory personnel only.

## Installation and Upgrade

There are several ways to install the software. The application
requires python3.

For Linux, at present, installation using `pip` is recommended. It is
expected that `pip` solution would work for Mac as well.

For Windows, `conda` solution is recommended for users that don't have
Python installed already. Otherwise, if using other than Anaconda
Python, consider using `pip` solution.

### pip

To be able to install PyQt5 using pip, you have to use python3.5 or
higher. If not available in the system, you can replace `pip3` command
below with `python3 -m pip`.

To install published version, run

```
pip3 install --user iocbio.kinetics
```
This will install all dependencies and it is expected to add a command `iocbio-kinetics` into your `PATH`. 
If the command is missing after installation, check whether the default location
of `pip3` installation is in your path. For Linux, it should be `~/.local/bin`.

To install, use the Git repository directly, for HTTPS users:
```
pip3 install --user git+https://gitlab.com/iocbio/kinetics
```
and for SSH users:
```
python3 -m pip install --user git+ssh://git@gitlab.com/iocbio/kinetics.git
```


For development, use

```
pip3 install --user -e .
```

in the source directory. To install the current version from the source, use

```
pip3 install --user .
```

Note that `--user` is recommended to avoid messing up the system
packages.

For upgrade, add `--upgrade` after install keyword. For example,
```
pip3 install --upgrade --user git+https://gitlab.com/iocbio/kinetics
```
or
```
python3 -m pip install --upgrade --user git+ssh://git@gitlab.com/iocbio/kinetics.git
```

### conda (Anaconda or Miniconda3)

Installation by conda is not supported at the moment. However, you can
install Anaconda environment and then use pip3 solution above in
Anaconda Prompt.

#### Installation Anaconda

Install Anaconda Python environment by downloading it from
https://www.anaconda.com/ . The package uses Python 3 language, so,
the version supporting it should be installed. At the moment of
writing, its Python 3.6.

#### Installation of channels

For installation from GUI:
* Start Anaconda Navigator
* Add channels by clicking "Channels" on the main screen and adding:
    * conda-forge

For installation from CLI, start Anaconda Prompt. In the prompt, add channels:
```
conda config --append channels conda-forge
conda config --append channels iocbio
```
and install software
```
conda install -c iocbio iocbio-kinetics
```
and you are all set.


For running iocbio.kinetics in Windows, its possible to start it as an
application from Anaconda Navigator or, directly, from starting
`iocbio-kinetics` in `Anaconda/Scripts` directory. For convenience, a
shortcut can be created on desktop or Start Menu by the user.


## Use with R

If `iocbio-banova` is used, some additional packges are needed. Install them following packages in R:

```
install.packages(c("tidyverse", "BayesFactor"))
```


## Making packages

For making source package, run

```
python3 setup.py sdist
```


For Conda packages, install conda (miniconda3 or anaconda3), `conda-build`, and run
```
conda-build -c anaconda -c conda-forge .
```
in `packaging/conda` subfolder.


## Copyright

Copyright (C) 2018 Laboratory of Systems Biology, Department of
Cybernetics, School of Science, Tallinn University of Technology
(https://sysbio.ioc.ee).

Software license: GPLv3, see [LICENSE](LICENSE).

Contact: Marko Vendelin <markov@sysbio.ioc.ee>
